import {Component, Inject, OnInit, PLATFORM_ID} from '@angular/core';
import {MenubarModule} from 'primeng/menubar';
import {MessageService} from 'primeng/api';
import {FloatLabelModule} from 'primeng/floatlabel';
import {ToastModule} from 'primeng/toast';
import {DialogModule} from 'primeng/dialog';
import {isPlatformBrowser} from '@angular/common';
import {Button} from 'primeng/button';
import {AuthService} from './auth.service';
import {CookieService} from 'ngx-cookie-service';

@Component({
  selector: 'app-root',
  standalone: true,
  imports: [MenubarModule, FloatLabelModule, ToastModule, DialogModule, Button],
  providers: [
    MessageService,
  ],
  templateUrl: './app.component.html',
  styleUrl: './app.component.css'
})
export class AppComponent implements OnInit {
  isSessionExpired: boolean = false;

  constructor(@Inject(PLATFORM_ID) private platformId: object,
              private authService: AuthService,
              private cookieService: CookieService) {
  }

  isBrowser(): boolean {
    return isPlatformBrowser(this.platformId);
  }

  setSessionExpiredFalse(): void {
    this.isSessionExpired = false;
    this.authService.setSessionExpired(false);
  }

  ngOnInit(): void {
    this.authService.sessionExpired$.subscribe(expired => {
      this.isSessionExpired = expired;
    });
  }
}
