import {Component, OnInit} from '@angular/core';
import {CookieService} from 'ngx-cookie-service';
import {HeaderComponent} from '../../components/header/header.component';
import {Router} from '@angular/router';
import {MessageService} from 'primeng/api';
import {ConfigurationService} from '../../configuration.service';

@Component({
  selector: 'app-logout',
  standalone: true,
  imports: [
    HeaderComponent
  ],
  templateUrl: './logout.component.html',
  styleUrl: './logout.component.css'
})
export class LogoutComponent implements OnInit{

  constructor(private cookieService: CookieService,
              private messageService: MessageService,
              private router: Router,
              private configurationService: ConfigurationService,) { }
  ngOnInit(): void {
    const routes: string[] = ['/', '/login', '/register', '/logout', '/profile', '/post', '/new-post', '/admin']
    Object.keys(this.cookieService.getAll()).forEach(key => {
      routes.forEach(route => {
        this.cookieService.delete(key, route, this.configurationService.getDomain());
      })
    });
    this.router.navigate(['/']).then(() => this.successMessage('Déconnexion', 'Vous avez été deconnecté avec succès'));
  }

  successMessage(summary: string, detail: string): void {
    this.messageService.add({
      severity: 'success',
      summary: summary,
      detail: detail,
      life: 3000,
      closable: false
    });
  }

}
